# Templates

The template system for reusable, parameterized video generation.

## Template

::: pymotion.template.base.Template

## TemplateValidationError

::: pymotion.template.base.TemplateValidationError
